# *****************************************************************************
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Module authors:
#   Markus Zolliker <markus.zolliker@psi.ch>
#
# *****************************************************************************

from os.path import expanduser
from configparser import ConfigParser
from servicemanager.base import ServiceManager


class FeederManager(ServiceManager):
    group = 'feeder'
    services = ('central', 'local')
    USAGE = """
    Usage:

      feeder start <instance> <service>
      feeder restart <instance> <service>
      feeder stop <instance> <service>
      feeder list [<instance>]

      %s
    """

    def __init__(self):
        parser = ConfigParser()
        parser.read(expanduser('~/.config/sehistory'))
        services = tuple(s for s in self.services if s in parser.sections())
        self.services = services
        super().__init__()

    def treat_args(self, argdict, unknown=(), extra=()):
        if not argdict.get('ins'):
            argdict['ins'] = self.single_ins
        return super().treat_args(argdict, unknown, extra)
